{ lib
, fetchPypi
, buildPythonPackage
, poetry-core
, lxml
, docopt-ng
, typing-extensions
, importlib-metadata
, importlib-resources
, pytestCheckHook
, mock
}:

buildPythonPackage rec {
  pname = "rnginline";
  version = "1.0.0";

  src = fetchPypi {
    inherit pname version;
    hash = "sha256-JWqzs+OqOynIAWYVgGrZiuiCqObAgGe6rBt0DcP3U6E=";
  };

  format = "pyproject";

  postPatch = ''
    substituteInPlace pyproject.toml \
      --replace 'importlib-metadata = "^6.6.0"' 'importlib-metadata = "^6.0.0"'
  '';

  nativeBuildInputs = [
    poetry-core
  ];

  propagatedBuildInputs = [
    docopt-ng
    lxml
    typing-extensions
    importlib-metadata
    importlib-resources
  ];

  nativeCheckInputs = [
    mock
    pytestCheckHook
  ];

  pythonImportsCheck = [ "rnginline" ];

  meta = with lib; {
    description = "A Python library and command-line tool for loading multi-file RELAX NG schemas from arbitary URLs, and flattening them into a single RELAX NG schema";
    homepage = "https://github.com/h4l/rnginline";
    license = licenses.asl20;
    maintainers = with maintainers; [ lesuisse ];
  };
}
